@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
-
+#pragma once
 #include "actionsmodel.h"
 #include <KActionCollection>
 #include <QObject>
@@ -18,7 +18,7 @@ public:
     Q_INVOKABLE void configureShortcuts();
     Q_INVOKABLE QAction *action(const QString &actionName);
 
-    virtual QVector<KActionCollection *> actionCollections() const = 0;
+    virtual QList<KActionCollection *> actionCollections() const = 0;
     QSortFilterProxyModel *actionsModel();
 
 Q_SIGNALS:
